<?php

class Widget_Newsmag_Identity extends WP_Widget {

	function __construct() {
		add_action( 'admin_init', array( $this, 'enqueue' ) );
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue' ) );
		add_action( 'customize_preview_init', array( $this, 'enqueue' ) );

		parent::__construct( 'newsmag_widget_identity', __( 'Newsmag - Identity', 'newsmag-pro' ), array(
			'classname'                   => 'newsmag_identity',
			'description'                 => __( 'A simple identity widget', 'newsmag-pro' ),
			'customize_selective_refresh' => true
		) );
	}

	public function enqueue() {

	}

	public function form( $instance ) {
		wp_enqueue_media();
		wp_enqueue_style( 'newsmag_media_upload_css', get_template_directory_uri() . '/inc/assets/css/upload-media.css' );
		wp_enqueue_script( 'newsmag_media_upload_js', get_template_directory_uri() . '/inc/assets/js/upload-media.js', array( 'jquery' ) );

		$defaults = array(
			'image_id'    => '',
			'social_menu' => '',
			'title'       => ''
		);

		if ( get_theme_mod( 'custom_logo' ) ) {
			$defaults['image_id'] = get_theme_mod( 'custom_logo' );
		}

		if ( get_option( 'blogname' ) ) {
			$defaults['title'] = get_option( 'blogname' );
		}

		// Merge the user-selected arguments with the defaults.
		$instance = wp_parse_args( (array) $instance, $defaults );

		// Loads the widget form.
		?>
		<p>
			<label><?php _e( 'Site title', 'newsmag-pro' ); ?> </label>
			<input type="text" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>"
			       id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"
			       value="<?php echo esc_attr( $instance['title'] ); ?>">
		</p>
		<p class="newsmag-media-control"
		   data-delegate-container="<?php echo esc_attr( $this->get_field_id( 'image_id' ) ) ?>">
			<label style="display:block"
			       for="<?php echo esc_attr( $this->get_field_id( 'image_id' ) ); ?>"><?php _e( 'Logo', 'newsmag-pro' );
				?>:</label>

			<?php echo wp_get_attachment_image( $instance['image_id'], false, false ); ?>

			<input type="hidden"
			       name="<?php echo esc_attr( $this->get_field_name( 'image_id' ) ); ?>"
			       id="<?php echo esc_attr( $this->get_field_id( 'image_id' ) ); ?>"
			       value="<?php echo (int) $instance['image_id']; ?>"
			       class="image-id blazersix-media-control-target">

			<button type="button" class="button upload-button"><?php _e( 'Choose Image', 'newsmag-pro' ); ?></button>
			<button type="button" class="button remove-button"><?php _e( 'Remove Image', 'newsmag-pro' ); ?></button>
		</p>
		<?php
		$menus = wp_get_nav_menus();
		?>
		<p>
			<?php if ( ! empty( $menus ) ) { ?>
				<label style="display:block"
				       for="<?php echo esc_attr( $this->get_field_id( 'social_menu' ) ); ?>"><?php _e( 'Social menu', 'newsmag-pro' ); ?>
					:</label>
				<select name="<?php echo esc_attr( $this->get_field_name( 'social_menu' ) ); ?>"
				        id="<?php echo esc_attr( $this->get_field_id( 'social_menu' ) ); ?>">
					<?php foreach ( $menus as $menu ) { ?>
						<option
							value="<?php echo $menu->slug; ?>" <?php selected( esc_attr( $menu->slug ), $instance['social_menu'] ); ?>><?php echo $menu->name; ?></option>
					<?php } ?>
				</select>
			<?php } else { ?>
				<?php echo __( 'Register menus first', 'newsmag-pro' ); ?>
			<?php } ?>
		</p>
	<?php }

	public function update( $new_instance, $old_instance ) {
		$instance                = $old_instance;
		$instance['image_id']    = (int) esc_html( $new_instance['image_id'] );
		$instance['social_menu'] = esc_attr( $new_instance['social_menu'] );
		$instance['title']       = esc_html( $new_instance['title'] );

		return $instance;
	}

	public function widget( $args, $instance ) {

		extract( $args, EXTR_SKIP );

		if ( empty( $instance['title'] ) ) {
			$instance['title'] = get_option( 'blogname' );;
		}

		echo $before_widget;
		$filepath = get_template_directory() . '/inc/widgets/identity/layouts/default.php';

		if ( file_exists( $filepath ) ) {
			include $filepath;
		} else {
			echo _e( 'Please configure your widget', 'newsmag-pro' );
		}

		echo $after_widget;
	}

}