<?php

class Widget_Newsmag_PopularPosts extends WP_Widget {
	function __construct() {

		add_action( 'admin_init', array( $this, 'enqueue' ) );
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue' ) );
		add_action( 'customize_preview_init', array( $this, 'enqueue' ) );

		parent::__construct( 'newsmag-popular-posts-widget', __( 'Newsmag - Popular Posts', 'newsmag-pro' ),
		                     array(
			                     'description'                 => __( 'Displays posts with most comments.', 'newsmag-pro' ),
			                     'classname'                   => 'popular-posts',
			                     'customize_selective_refresh' => true
		                     ) );

	}

	public function enqueue() {
		wp_enqueue_script( 'jquery-ui' );
		wp_enqueue_script( 'jquery-ui-slider' );
		wp_enqueue_style( 'epsilon-styles', get_template_directory_uri() . '/inc/customizer/epsilon-framework/assets/css/style.css' );
		wp_enqueue_script( 'epsilon-object', get_template_directory_uri() . '/inc/customizer/epsilon-framework/assets/js/epsilon.js', array( 'jquery' ) );
	}

	public function form( $instance ) {
		$instance['title']     = isset( $instance['title'] ) ? $instance['title'] : '';
		$instance['show_post'] = isset( $instance['show_post'] ) ? $instance['show_post'] : 5;
		$instance['show_date'] = isset( $instance['show_date'] ) ? $instance['show_date'] : 'on';
		?>
		<p>
			<label><?php _e( 'Title', 'newsmag-pro' ); ?> :</label>
			<input type="text" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>"
			       id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"
			       value="<?php echo esc_attr( $instance['title'] ); ?>">
		</p>

		<label class="block" for="input_<?php echo esc_attr( $this->get_field_id( 'show_post' ) ); ?>">
            <span class="customize-control-title">
               <?php _e( 'Posts to Show', 'newsmag-pro' ); ?> :
            </span>
		</label>

		<input type="text" name="<?php echo esc_attr( $this->get_field_name( 'show_post' ) ); ?>" class="rl-slider"
		       id="input_<?php echo esc_attr( $this->get_field_id( 'show_post' ) ); ?>"
		       value="<?php echo esc_attr( $instance['show_post'] ); ?>"/>

		<div id="slider_<?php echo esc_attr( $this->get_field_id( 'show_post' ) ) ?>" data-attr-min="1"
		     data-attr-max="10" data-attr-step="1" class="ss-slider"></div>
		<script>
			jQuery(document).ready(function ($) {
				$('[id="slider_<?php echo esc_attr( $this->get_field_id( 'show_post' ) ); ?>"]').slider({
					value: <?php echo esc_attr( $instance['show_post'] ); ?>,
					range: 'min',
					min  : 1,
					max  : 10,
					step : 1,
					slide: function (event, ui) {
						$('[id="input_<?php echo esc_attr( $this->get_field_id( 'show_post' ) ); ?>"]').val(ui.value).keyup();
					}
				});
				$('[id="input_<?php echo esc_attr( $this->get_field_id( 'show_post' ) ) ?>"]').on('focus', function () {
					$('[id="input_<?php echo esc_attr( $this->get_field_id( 'show_post' ) ) ?>"]').trigger('blur');
				});
				$('[id="input_<?php echo esc_attr( $this->get_field_id( 'show_post' ) ) ?>"]').val($('[id="slider_<?php echo esc_attr( $this->get_field_id( 'show_post' ) ) ?>"]').slider("value"));
				$('[id="input_<?php echo esc_attr( $this->get_field_id( 'show_post' ) ) ?>"]').change(function () {
					$('[id="slider_<?php echo esc_attr( $this->get_field_id( 'show_post' ) ) ?>"]').slider({
						value: $(this).val()
					});
				});
			});
		</script>

		<div class="checkbox_switch">
				<span class="customize-control-title onoffswitch_label">
                    <?php _e( 'Show Date', 'newsmag-pro' ); ?>
				</span>
			<div class="onoffswitch">
				<input type="checkbox" id="<?php echo esc_attr( $this->get_field_name( 'show_date' ) ); ?>"
				       name="<?php echo esc_attr( $this->get_field_name( 'show_date' ) ); ?>"
				       class="onoffswitch-checkbox"
				       value="on"
					<?php checked( $instance['show_date'], 'on' ); ?>>
				<label class="onoffswitch-label"
				       for="<?php echo esc_attr( $this->get_field_name( 'show_date' ) ); ?>"></label>
			</div>
		</div>

	<?php }

	public function update( $new_instance, $old_instance ) {

		$instance = array();

		$instance['title']     = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		$instance['show_post'] = ( ! empty( $new_instance['show_post'] ) ) ? strip_tags( $new_instance['show_post'] ) : '';
		$instance['show_date'] = ( ! empty( $new_instance['show_date'] ) ) ? $new_instance['show_date'] : '';

		return $instance;

	}

	/**
	 * Proxy function to return posts
	 *
	 * @param $instance
	 *
	 * @return WP_Query
	 */
	public function get_posts( $instance ) {
		$args = array(
			'orderby'             => 'comment_count',
			'posts_per_page'      => $instance['show_post'],
			'ignore_sticky_posts' => true,
		);

		$query = new WP_Query( $args );

		wp_reset_postdata();

		return $query;
	}

	public function widget( $args, $instance ) {
		extract( $args );
		extract( $instance );

		wp_enqueue_script( 'newsmag-popular-posts-script', get_template_directory_uri() . '/inc/widgets/popularposts/assets/js/popularposts.js', array( 'jquery' ) );

		$instance['title']     = isset( $instance['title'] ) ? $instance['title'] : '';
		$instance['show_post'] = isset( $instance['show_post'] ) ? $instance['show_post'] : 5;
		$instance['show_date'] = isset( $instance['show_date'] ) ? $instance['show_date'] : 'on';

		$posts = $this->get_posts( $instance );
		echo $before_widget;
		?>
		<div class="col-md-4 newsmag-popular-posts">
			<h2>
				<span><?php echo ! empty( $instance['title'] ) ? esc_html( $instance['title'] ) : esc_html( __( 'Popular Posts', 'newsmag-pro' ) ); ?></span>
			</h2>
			<div class="newsmag-popular-posts-filter">
				<?php echo '<span class="holder">' . __( 'THIS:', 'newsmag-pro' ) . '</span>'; ?>

				<a href="#" data-filter="all" class="active"><?php echo __( 'ALL TIME', 'newsmag-pro' ) ?></a>
				<a href="#" data-filter="week"><?php echo __( 'WEEK', 'newsmag-pro' ) ?></a>
				<a href="#" data-filter="month"><?php echo __( 'MONTH', 'newsmag-pro' ) ?></a>

			</div>
			<ul class="posts-list">
				<?php while ( $posts->have_posts() ) : $posts->the_post();

					$image = '<img class="attachment-newsmag-recent-post-big size-newsmag-recent-post-big wp-post-image" alt="" src="' . get_template_directory_uri() . '/assets/images/picture_placeholder_list.jpg" />';

					if ( has_post_thumbnail() ) {
						$image = get_the_post_thumbnail( get_the_ID(), 'newsmag-recent-post-list-image' );
					}
					$image_obj = array( 'id' => get_the_ID(), 'image' => $image );

					$new_image    = apply_filters( 'newsmag_widget_image', $image_obj );
					$allowed_tags = array(
						'img'      => array(
							'data-srcset' => true,
							'data-src'    => true,
							'srcset'      => true,
							'sizes'       => true,
							'src'         => true,
							'class'       => true,
							'alt'         => true,
							'width'       => true,
							'height'      => true
						),
						'noscript' => array()
					);
					?>
					<li>

						<a href="<?php the_permalink() ?>">
							<?php echo wp_kses( $new_image, $allowed_tags ); ?>
						</a>

						<div class="content">
							<a href="<?php the_permalink(); ?>"
							   title="<?php echo esc_attr( get_the_title() ? get_the_title() : get_the_ID() ); ?>">
								<?php if ( get_the_title() ) {
									the_title();
								} else {
									the_ID();
								} ?></a>
							<div class="meta">
								<span class="fa fa-clock-o"></span> <?php echo esc_html( get_the_date() ); ?>
								<?php if ( current_user_can( 'manage_options' ) ) { ?>
									<a class="newsmag-comments-link " target="_blank"
									   href="<?php echo get_admin_url() . 'post.php?post=' . get_the_ID() . '&action=edit' ?>">
										<span class="fa fa-edit"></span> <?php echo __( 'Edit', 'newsmag-pro' ) ?>
									</a>
								<?php } ?>
							</div>

						</div>

					</li>
				<?php endwhile; ?>
			</ul>
		</div>
		<?php
		echo $after_widget;
	}
}

add_action( 'wp_ajax_newsmag_get_latest_posts', 'newsmag_get_latest_posts' );
add_action( 'wp_ajax_nopriv_newsmag_get_latest_posts', 'newsmag_get_latest_posts' );

function newsmag_get_latest_posts() {

	$allowed_values = array( 'all', 'week', 'month' );

	if ( ! in_array( esc_html( $_POST['filter'] ), $allowed_values ) ) {
		$_POST['filter'] = 'week';
	}

	$args = array(
		'orderby'        => array( 'comment_count' => 'DESC' ),
		'posts_per_page' => absint( $_POST['length'] ),
		'date_query'     => array(
			array(
				'after' => '1 ' . esc_html( $_POST['filter'] ) . ' ago'
			)
		)
	);

	if ( $_POST['filter'] === 'all' ) {
		unset( $args['date_query'] );
	}

	$query  = new WP_Query( $args );
	$return = array();
	while ( $query->have_posts() ) : $query->the_post();
		$image = '<img class="attachment-newsmag-recent-post-big size-newsmag-recent-post-big wp-post-image" alt="" src="' . esc_url_raw( get_template_directory_uri() . '/assets/images/picture_placeholder_list.jpg' ) . '" />';
		if ( has_post_thumbnail() ) {
			$image = get_the_post_thumbnail( get_the_ID(), 'newsmag-recent-post-list-image' );
		}

		$meta = '<span class="fa fa-clock-o"></span> ' . esc_html( get_the_date() );
		if ( current_user_can( 'manage_options' ) ) {
			$meta .= '<a class="newsmag-comments-link " target="_blank" href="' . get_admin_url() . 'post.php?post=' . get_the_ID() . '&action=edit">';
			$meta .= '<span class="fa fa-edit"></span>' . __( 'Edit', 'newsmag-pro' ) . '</a>';
		}

		$return[] = array(
			'id'        => get_the_ID(),
			'thumb'     => wp_kses_post( $image ),
			'permalink' => esc_url_raw( get_the_permalink() ),
			'title'     => esc_html( get_the_title() ),
			'meta'      => $meta,
		);
	endwhile;
	wp_reset_postdata();
	wp_reset_query();

	echo json_encode( $return );
	unset( $return );
	wp_die();
}